Stan Math Library: stan/math/prim/arr/meta/length.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

length.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_ARR_META_LENGTH_HPP
2 #define STAN_MATH_PRIM_ARR_META_LENGTH_HPP
3
4 #include <cstdlib>
5 #include <vector>
6
7 namespace stan {
8
9 template <typename T>
10 size_t length(const std::vector<T>& x) {
11 return x.size();
12 }
13 }
14 #endif
15
stan
Definition: log_sum_exp.hpp:8
stan::length
size_t length(const std::vector< T > &x)
Definition: length.hpp:10

[ Stan Home Page ] © 2011–2016, Stan Development Team.